@@ -1301,11 +1301,6 @@ RunUMAP.default <- function(
         )
       }
       if (is.list(x = object)) {
-        if (packageVersion(pkg = "uwot") <= '0.1.8.9000') {
-          stop("This uwot functionality requires uwot version >= 0.1.8.9000",
-               "Installing the latest version from github can be done with",
-               "remotes::install_github('jlmelville/uwot')")
-        }
         uwot::umap_transform(
           X = NULL,
           nn_method = object,
