@@ -418,9 +418,13 @@ CaseMatch <- function(search, match) {
 #' @param object A Seurat object
 #' @param s.features A vector of features associated with S phase
 #' @param g2m.features A vector of features associated with G2M phase
+#' @param ctrl Number of control features selected from the same bin per
+#' analyzed feature supplied to \code{\link{AddModuleScore}}.
+#' Defaults to value equivalent to minimum number of features
+#' present in 's.features' and 'g2m.features'.
 #' @param set.ident If true, sets identity to phase assignments
-#' @param ... Arguments to be passed to \code{\link{AddModuleScore}}
 #' Stashes old identities in 'old.ident'
+#' @param ... Arguments to be passed to \code{\link{AddModuleScore}}
 #'
 #' @return A Seurat object with the following columns added to object meta data: S.Score, G2M.Score, and Phase
 #'
@@ -445,16 +449,20 @@ CellCycleScoring <- function(
   object,
   s.features,
   g2m.features,
+  ctrl = NULL,
   set.ident = FALSE,
   ...
 ) {
   name <- 'Cell.Cycle'
   features <- list('S.Score' = s.features, 'G2M.Score' = g2m.features)
+  if (is.null(x = ctrl)) {
+    ctrl <- min(vapply(X = features, FUN = length, FUN.VALUE = numeric(length = 1)))
+  }
   object.cc <- AddModuleScore(
     object = object,
     features = features,
     name = name,
-    ctrl = min(vapply(X = features, FUN = length, FUN.VALUE = numeric(length = 1))),
+    ctrl = ctrl,
     ...
   )
   cc.columns <- grep(pattern = name, x = colnames(x = object.cc[[]]), value = TRUE)
@@ -2102,6 +2110,7 @@ RandomName <- function(length = 5L, ...) {
 # @return Returns x
 #
 Same <- function(x) {
+  .Deprecated(new = 'base::identity', package = NULL)
   return(x)
 }
 
