@@ -26,3 +26,25 @@ test_that("Read10X handles missing files properly", {
   expect_error(Read10X("./notadir/"))
   expect_error(Read10X(dname, gene.column = 10))
 })
+
+# Tests for reading in spatial 10x data
+context("Load10X_Spatial")
+dname <- "../testdata/visium"
+# txsp <- Read10X_Spatial(outs_path = "../testdata/visium/")
+txsp <- Load10X_Spatial(data.dir = '../testdata/visium')
+
+test_that("10x Spatial Data Parsing", {
+  expect_is(txsp, "Seurat")
+  expect_equal(ncol(x = txsp), 2695)
+  expect_equal(nrow(x = txsp), 100)
+  expect_equal(Cells(x = txsp)[1], "AAACAAGTATCTCCCA-1")
+  expect_equal(Assays(object = txsp), "Spatial")
+  expect_equal(GetAssayData(object = txsp[["Spatial"]], slot = "counts")[5, 9], 1)
+})
+
+test_that("Read10X_Spatial handles missing files properly", {
+  expect_error(Load10X_Spatial(data.dir = "."))
+  expect_error(Load10X_Spatial(data.dir = "./notadir/"))
+})
+
+
